==> knowledge-center-api-0.1.10-sources.jar: cn/yoofans/knowledge/center/api/dto/comment/CommentStateDto.java <==
package cn.yoofans.knowledge.center.api.dto.comment;

import java.io.Serializable;

import org.apache.commons.lang3.builder.ToStringBuilder;

/**
 * Created by zhangshun on 2018/5/25,11:35:12.
 */
public class CommentStateDto implements Serializable {

    private String date;

    private Integer day;

    private Long userId;

    private Long readId;

    private Long courseId;

    private Long commentId;

    private Boolean clockState;

    private Boolean commentState;

    private Boolean afterToday;

    private Boolean lackCard;

    public String getDate() {
        return date;
    }

    public void setDate(String date) {
        this.date = date;
    }

    public Integer getDay() {
        return day;
    }

    public void setDay(Integer day) {
        this.day = day;
    }

    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }

    public Long getReadId() {
        return readId;
    }

    public void setReadId(Long readId) {
        this.readId = readId;
    }

    public Long getCourseId() {
        return courseId;
    }

    public void setCourseId(Long courseId) {
        this.courseId = courseId;
    }

    public Long getCommentId() {
        return commentId;
    }

    public void setCommentId(Long commentId) {
        this.commentId = commentId;
    }

    public Boolean getClockState() {
        return clockState;
    }

    public void setClockState(Boolean clockState) {
        this.clockState = clockState;
    }

    public Boolean getCommentState() {
        return commentState;
    }

    public void setCommentState(Boolean commentState) {
        this.commentState = commentState;
    }

    public Boolean getAfterToday() {
        return afterToday;
    }

    public void setAfterToday(Boolean afterToday) {
        this.afterToday = afterToday;
    }

    public Boolean getLackCard() {
        return lackCard;
    }

    public void setLackCard(Boolean lackCard) {
        this.lackCard = lackCard;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);
    }
}

==> knowledge-center-api-0.3.5-sources.jar: cn/yoofans/knowledge/center/api/dto/comment/CommentStateDto.java <==
package cn.yoofans.knowledge.center.api.dto.comment;

import java.io.Serializable;

import org.apache.commons.lang3.builder.ToStringBuilder;

/**
 * Created by zhangshun on 2018/5/25,11:35:12.
 */
public class CommentStateDto implements Serializable {

    private String date;

    private Integer day;

    private Long userId;

    private Long readId;

    private Long courseId;

    private Long commentId;

    private Boolean clockState;

    private Boolean commentState;

    private Boolean afterToday;

    private Boolean lackCard;

    private Boolean replenish;//是否补学,true-补学

    public String getDate() {
        return date;
    }

    public void setDate(String date) {
        this.date = date;
    }

    public Integer getDay() {
        return day;
    }

    public void setDay(Integer day) {
        this.day = day;
    }

    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }

    public Long getReadId() {
        return readId;
    }

    public void setReadId(Long readId) {
        this.readId = readId;
    }

    public Long getCourseId() {
        return courseId;
    }

    public void setCourseId(Long courseId) {
        this.courseId = courseId;
    }

    public Long getCommentId() {
        return commentId;
    }

    public void setCommentId(Long commentId) {
        this.commentId = commentId;
    }

    public Boolean getClockState() {
        return clockState;
    }

    public void setClockState(Boolean clockState) {
        this.clockState = clockState;
    }

    public Boolean getCommentState() {
        return commentState;
    }

    public void setCommentState(Boolean commentState) {
        this.commentState = commentState;
    }

    public Boolean getAfterToday() {
        return afterToday;
    }

    public void setAfterToday(Boolean afterToday) {
        this.afterToday = afterToday;
    }

    public Boolean getLackCard() {
        return lackCard;
    }

    public void setLackCard(Boolean lackCard) {
        this.lackCard = lackCard;
    }

    public Boolean getReplenish() {
        return replenish;
    }

    public void setReplenish(Boolean replenish) {
        this.replenish = replenish;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);
    }
}
